summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTristan Van Berkom <tristan.van.berkom@gmail.com>2010-09-02 14:22:55 +0900
committerTristan Van Berkom <tristan.van.berkom@gmail.com>2010-09-02 14:22:55 +0900
commitc9ccc7551b993d3c1c8627da84d66fd4b8c44b80 (patch)
tree928f69a012aa93168dac0a76b8158c56e71cea0e
parentf2279d5e5130382c78eedb59b5da2e47ebd9885a (diff)
downloadgtk+-c9ccc7551b993d3c1c8627da84d66fd4b8c44b80.tar.gz
Some api changes for GtkWrapBox
Ammended documentation for GTK_WRAP_BOX_SPREAD_EVEN and renamed GTK_WRAP_BOX_SPREAD_BEGIN -> GTK_WRAP_BOX_SPREAD_START.
-rw-r--r--gtk/gtkenums.h10
-rw-r--r--gtk/gtkwrapbox.c6
-rw-r--r--gtk/gtkwrapbox.h1
-rw-r--r--tests/testwrapbox.c4
4 files changed, 11 insertions, 10 deletions
diff --git a/gtk/gtkwrapbox.h b/gtk/gtkwrapbox.h
index 3fdfb1648c..30db2603d7 100644
--- a/gtk/gtkwrapbox.h
+++ b/gtk/gtkwrapbox.h
@@ -91,6 +91,7 @@ void gtk_wrap_box_insert_child (GtkWrapBox
gboolean yexpand,
gboolean xfill,
gboolean yfill);
+
void gtk_wrap_box_reorder_child (GtkWrapBox *layout,
GtkWidget *widget,
guint index);
diff --git a/tests/testwrapbox.c b/tests/testwrapbox.c
index 2ad26eb516..6b9f521a74 100644
--- a/tests/testwrapbox.c
+++ b/tests/testwrapbox.c
@@ -29,7 +29,7 @@ enum {
};
#define INITIAL_ALLOCATION_MODE GTK_WRAP_ALLOCATE_HOMOGENEOUS
-#define INITIAL_SPREADING GTK_WRAP_BOX_SPREAD_BEGIN
+#define INITIAL_SPREADING GTK_WRAP_BOX_SPREAD_START
#define INITIAL_MINIMUM_LENGTH 3
#define INITIAL_HSPACING 2
#define INITIAL_VSPACING 2
@@ -302,7 +302,7 @@ create_window (void)
/* Add Spreading control */
widget = gtk_combo_box_new_text ();
- gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Spread Begin");
+ gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Spread Start");
gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Spread End");
gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Spread Even");
gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Spread Expand");
diff --git a/gtk/gtkenums.h b/gtk/gtkenums.h
index 3523dc39db..e46d207265 100644
--- a/gtk/gtkenums.h
+++ b/gtk/gtkenums.h
@@ -559,15 +559,15 @@ typedef enum {
/**
* GtkWrapBoxSpreading:
* @GTK_WRAP_BOX_SPREAD_BEGIN: Items are allocated no more than their natural size
* in the layout's orientation and any extra space is left trailing at
* the end of each line.
- * @GTK_WRAP_BOX_SPREAD_END: Items are allocated no more than their natural size
+ * @GTK_WRAP_BOX_SPREAD_END: Children are allocated no more than their natural size
* in the layout's orientation and any extra space skipped at the beginning
* of each line.
- * @GTK_WRAP_BOX_SPREAD_EVEN: Items are allocated no more than their natural size
+ * @GTK_WRAP_BOX_SPREAD_EVEN: Children are allocated no more than their natural size
* in the layout's orientation and any extra space is evenly distributed
- * between children.
+ * as empty space between children.
* @GTK_WRAP_BOX_SPREAD_EXPAND: Items share the extra space evenly (or among children that 'expand' when
* in %GTK_WRAP_ALLOCATE_FREE mode.
*
@@ -582,7 +582,7 @@ typedef enum {
*
*/
typedef enum {
- GTK_WRAP_BOX_SPREAD_BEGIN = 0,
+ GTK_WRAP_BOX_SPREAD_START = 0,
GTK_WRAP_BOX_SPREAD_END,
GTK_WRAP_BOX_SPREAD_EVEN,
GTK_WRAP_BOX_SPREAD_EXPAND
@@ -559,15 +559,15 @@ typedef enum {
/**
* GtkWrapBoxSpreading:
- * @GTK_WRAP_BOX_SPREAD_BEGIN: Items are allocated no more than their natural size
+ * @GTK_WRAP_BOX_SPREAD_START: Children are allocated no more than their natural size
* in the layout's orientation and any extra space is left trailing at
* the end of each line.
diff --git a/gtk/gtkwrapbox.c b/gtk/gtkwrapbox.c
index 1238a50346..ee0d89e9dd 100644
--- a/gtk/gtkwrapbox.c
+++ b/gtk/gtkwrapbox.c
@@ -200,7 +200,7 @@ gtk_wrap_box_class_init (GtkWrapBoxClass *class)
P_("Spreading"),
P_("The spreading mode to use"),
GTK_TYPE_WRAP_BOX_SPREADING,
- GTK_WRAP_BOX_SPREAD_BEGIN,
+ GTK_WRAP_BOX_SPREAD_START,
GTK_PARAM_READWRITE));
@@ -382,7 +382,7 @@ gtk_wrap_box_init (GtkWrapBox *box)
priv->orientation = GTK_ORIENTATION_HORIZONTAL;
priv->mode = GTK_WRAP_ALLOCATE_FREE;
- priv->spreading = GTK_WRAP_BOX_SPREAD_BEGIN;
+ priv->spreading = GTK_WRAP_BOX_SPREAD_START;
priv->vertical_spacing = 0;
priv->horizontal_spacing = 0;
priv->children = NULL;
@@ -1036,7 +1036,7 @@ gtk_wrap_box_size_allocate (GtkWidget *widget,
if (priv->spreading != GTK_WRAP_BOX_SPREAD_EXPAND)
item_size = MIN (item_size, nat_item_size);
/* Get the real extra pixels incase of GTK_WRAP_BOX_SPREAD_BEGIN lines */
extra_pixels = avail_size - (line_length - 1) * item_spacing - item_size * line_length;
extra_per_item = extra_pixels / MAX (line_length -1, 1);
extra_extra = extra_pixels % MAX (line_length -1, 1);
@@ -1036,7 +1036,7 @@ gtk_wrap_box_size_allocate (GtkWidget *widget,
if (priv->spreading != GTK_WRAP_BOX_SPREAD_EXPAND)
item_size = MIN (item_size, nat_item_size);
- /* Get the real extra pixels incase of GTK_WRAP_BOX_SPREAD_BEGIN lines */
+ /* Get the real extra pixels incase of GTK_WRAP_BOX_SPREAD_START lines */
extra_pixels = avail_size - (line_length - 1) * item_spacing - item_size * line_length;
extra_per_item = extra_pixels / MAX (line_length -1, 1);